==> 1.0.4.tar.gz: zgo/src/app/items/items.service.ts <==
import { Item } from './item.model';
import { Injectable } from '@angular/core';
import { Subject, BehaviorSubject, Observable } from 'rxjs';
import { HttpClient, HttpParams, HttpHeaders } from '@angular/common/http';

@Injectable({providedIn: 'root'})

export class ItemService{
	beUrl = 'http://localhost:3000/';
	private dataStore: { items: Item[] } = { items: [] } ;
	private _itemsUpdated: BehaviorSubject<Item[]> = new BehaviorSubject(this.dataStore.items);
	public readonly itemsUpdated: Observable<Item[]> = this._itemsUpdated.asObservable();
	private address:string = '';
	private apiKey = 'Le2adeic8Thah4Aeng4daem6i';
	private reqHeaders: HttpHeaders;

	constructor(private http: HttpClient){
		this.reqHeaders = new HttpHeaders().set('Authorization', this.apiKey);
	}

	getItems(addr: string){
		this.address = addr;
		const params = new HttpParams().append('address', addr);
		let obs = this.http.get<{message: string, items: any}>(this.beUrl+'api/getitems', { headers:this.reqHeaders, params: params, observe: 'response'});

		obs.subscribe((ItemDataResponse) => {
			if (ItemDataResponse.status == 200 ) {
				this.dataStore.items = ItemDataResponse.body!.items;
				this._itemsUpdated.next(Object.assign({},this.dataStore).items);
			} else {
				this.dataStore.items = [];
				this._itemsUpdated.next(Object.assign({},this.dataStore).items);
				console.log('No items found');
			}
		});

		return obs;
	}

	addItem(item: Item) {
		//const params = new HttpParams().append('item', JSON.stringify(item));
		let obs = this.http.post<{message: string}>(this.beUrl+'api/item', { item: item }, { headers: this.reqHeaders });

		obs.subscribe((ItemResponse) => {
			console.log('Item added');
			this.getItems(this.address);
		});

		return obs;
	}

	deleteItem(id: string) {
		let obs = this.http.delete<{message: string}>(this.beUrl+'api/item/'+id, { headers: this.reqHeaders });

		obs.subscribe((ItemResponse) => {
			console.log('Item deleted');
			this.getItems(this.address);
		});

		return obs;
	}
}

==> 1.0.5.tar.gz: zgo/src/app/items/items.service.ts <==
import { Item } from './item.model';
import { Injectable } from '@angular/core';
import { Subject, BehaviorSubject, Observable } from 'rxjs';
import { HttpClient, HttpParams, HttpHeaders } from '@angular/common/http';

@Injectable({providedIn: 'root'})

export class ItemService{
	beUrl = 'http://localhost:3000/';
	private dataStore: { items: Item[] } = { items: [] } ;
	private _itemsUpdated: BehaviorSubject<Item[]> = new BehaviorSubject(this.dataStore.items);
	public readonly itemsUpdated: Observable<Item[]> = this._itemsUpdated.asObservable();
	private address:string = '';
	private apiKey = 'YourApiKey';
	private reqHeaders: HttpHeaders;

	constructor(private http: HttpClient){
		this.reqHeaders = new HttpHeaders().set('Authorization', this.apiKey);
	}

	getItems(addr: string){
		this.address = addr;
		const params = new HttpParams().append('address', addr);
		let obs = this.http.get<{message: string, items: any}>(this.beUrl+'api/getitems', { headers:this.reqHeaders, params: params, observe: 'response'});

		obs.subscribe((ItemDataResponse) => {
			if (ItemDataResponse.status == 200 ) {
				this.dataStore.items = ItemDataResponse.body!.items;
				this._itemsUpdated.next(Object.assign({},this.dataStore).items);
			} else {
				this.dataStore.items = [];
				this._itemsUpdated.next(Object.assign({},this.dataStore).items);
				console.log('No items found');
			}
		});

		return obs;
	}

	addItem(item: Item) {
		//const params = new HttpParams().append('item', JSON.stringify(item));
		let obs = this.http.post<{message: string}>(this.beUrl+'api/item', { item: item }, { headers: this.reqHeaders });

		obs.subscribe((ItemResponse) => {
			console.log('Item added');
			this.getItems(this.address);
		});

		return obs;
	}

	deleteItem(id: string) {
		let obs = this.http.delete<{message: string}>(this.beUrl+'api/item/'+id, { headers: this.reqHeaders });

		obs.subscribe((ItemResponse) => {
			console.log('Item deleted');
			this.getItems(this.address);
		});

		return obs;
	}
}
